:tocdepth: 4

Documentation for ANNarchy
===========================

ANNarchy (Artificial Neural Networks architect) is a neural simulator designed for distributed rate-coded or spiking neural networks. The core of the library is written in C++ and distributed using openMP or CUDA. It provides an interface in Python for the definition of the networks. It is released under the `GNU GPL v2 or later <http://www.gnu.org/licenses/gpl.html>`_.

The source code of ANNarchy can be downloaded at:

`http://bitbucket.org/annarchy/annarchy <http://bitbucket.org/annarchy/annarchy>`_

The documentation can be found online at:

`http://annarchy.readthedocs.io <http://annarchy.readthedocs.io>`_

A forum for discussion is set at:

`https://groups.google.com/forum/#!forum/annarchy <https://groups.google.com/forum/#!forum/annarchy>`_

Bug reports should be done through the `Issue Tracker <https://bitbucket.org/annarchy/annarchy/issues>`_ of ANNarchy on `Bitbucket <http://bitbucket.org>`_. You will need to create a free account.

**Citation**

If you use ANNarchy for your research, we would appreciate if you cite the following paper:

Vitay J, Dinkelbach HÜ and Hamker FH (2015). ANNarchy: a code generation approach to neural simulations on parallel hardware. *Frontiers in Neuroinformatics* 9:19. `doi:10.3389/fninf.2015.00019 <http://dx.doi.org/10.3389/fninf.2015.00019>`_



**Content**

.. toctree::
    :maxdepth: 2
    :numbered:

    Introduction.rst
    Manual.rst
    API.rst
    Example.rst
